%{!?tcl_version: %define tcl_version %(echo 'puts $tcl_version' | tclsh)}
%{!?tcl_sitearch: %define tcl_sitearch %{_libdir}/tcl%{tcl_version}}

%define contentdir %_var/www/tclhttpd
Name: tclhttpd
Version: 3.5.1
Release: %mkrel 9
Summary: Extensible Web+Application server written in Tcl

Group: Networking/WWW
License: TCL and BSD with advertising
URL:            https://tclhttpd.sourceforge.net/
Source0:        https://downloads.sourceforge.net/tclhttpd/tclhttpd3.5.1.tar.gz
Source1:        tclhttpd.service
Patch0:         tclhttpd_fedora.1.patch
Patch1:         tclhttpd-md5-3.5.1.patch
Patch2:         tclhttpd-3.5.1-nofork.patch
Patch3:         tclhttpd-3.5.1-mga-result.patch
Patch4:         tclhttpd-fix-building-with-gcc14.patch

BuildRequires: pkgconfig(tcl)
BuildRequires: systemd-units

Requires: tcl tclx tcl-tcllib
Requires(pre): shadow-utils
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units

%description
TclHttpd is a Web server implemented in pure Tcl. It works out of the box as a
Web server, but is really designed to be a Tcl application server. It supports
HTML+Tcl templates, and is extensible in a variety of ways.

This web server is legacy software but is included as it is needed by
some astronomy related software that uses httpd for RPC purposes.

%prep
%setup -q -n %{name}%{version}
%autopatch -p1

%build
%configure --with-serverroot=%{contentdir}
%make_build

%install
make install DESTDIR=$RPM_BUILD_ROOT \
     datadir=%{tcl_sitelib}
mkdir -p $RPM_BUILD_ROOT/%{_unitdir}
install -p -D %{SOURCE1} $RPM_BUILD_ROOT/%{_unitdir}/
mkdir -p $RPM_BUILD_ROOT%_var/run/tclhttpd

# Move some of the libraries around so that we don't pollute the libdir.
# Eventually this fix should be put into the Makefile.
mkdir -p $RPM_BUILD_ROOT%{tcl_sitearch}
mv $RPM_BUILD_ROOT%{_libdir}/liblimit1.0.so $RPM_BUILD_ROOT%{_libdir}/limit1.0/
mv $RPM_BUILD_ROOT%{_libdir}/libcrypt1.0.so $RPM_BUILD_ROOT%{_libdir}/crypt1.0/
sed -e 's# \.\. # . #' < limit_pkgIndex.tcl > $RPM_BUILD_ROOT%{_libdir}/limit1.0/pkgIndex.tcl
sed -e 's# \.\. # . #' < crypt_pkgIndex.tcl > $RPM_BUILD_ROOT%{_libdir}/crypt1.0/pkgIndex.tcl
mv $RPM_BUILD_ROOT%{_libdir}/limit1.0 $RPM_BUILD_ROOT%{tcl_sitearch}/
mv $RPM_BUILD_ROOT%{_libdir}/crypt1.0 $RPM_BUILD_ROOT%{tcl_sitearch}/

# Replace the numeric id in this configuration file with a name.  We don't
# know what numeric id it will end up with when it's created during
# the rpm installation.  Move the tclhttpd.rc file to a configuration
# directory so that it doesn't pollute the bin directory.
mkdir -p $RPM_BUILD_ROOT/%_sysconfdir/%{name}
mkdir -p $RPM_BUILD_ROOT/%_var/log/tclhttpd

# Set the user that tclhttpd will run as.
# Set the group that tclhttpd will run as.
# Set the default log file location.
# Turn off the debug password authorization for security reasons.
#    It can be turned on manually if needed.
sed -e 's/Config uid.*/Config uid tclhttpd/' \
        -e 's/Config gid.*/Config gid tclhttpd/' \
        -e 's#Config SSL_CADIR.*#Config SSL_CADIR "/etc/pki/tls/certs/"#' \
        -e 's#Config SSL_CAFILE.*#Config SSL_CAFILE "/etc/pki/tls/certs/ca-bundle.crt"#' \
        -e 's#Config SSL_CERTFILE.*#Config SSL_CERTFILE     [file join [Config SSL_CADIR] tclhttpd.pem]#' \
        -e 's#Config SSL_KEYFILE.*#Config SSL_KEYFILE     [file join [Config SSL_CADIR] tclhttpdkey.pem]#' \
        -e 's#Config LogFile.*#Config LogFile %_var/log/tclhttpd/log#' \
        -e 's/#Config Auth {}/Config Auth {}/' < bin/tclhttpd.rc > $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}/tclhttpd.rc
sed -e 's/^Debug_Url.*/#&/' < bin/httpdthread.tcl > $RPM_BUILD_ROOT/%{tcl_sitelib}/%{name}%{version}/httpdthread.tcl

rm $RPM_BUILD_ROOT/%{_prefix}/bin/tclhttpd.rc
rm $RPM_BUILD_ROOT/%{_prefix}/bin/httpdthread.tcl
rm $RPM_BUILD_ROOT/%{contentdir}/tclhttpd.etc.init
# This cgi is precompiled and has some old libc dependencies.  It's been
# removed in the CVS head.  Until the next version is released, we remove
# it by hand here.
rm $RPM_BUILD_ROOT/%{contentdir}/htdocs/cgi-bin/env
mv $RPM_BUILD_ROOT/%{_prefix}/bin/httpd.tcl $RPM_BUILD_ROOT/%{_prefix}/bin/tclhttpd

# Creating ghosted files
mkdir -p $RPM_BUILD_ROOT/%{_var}/lock/subsys
touch $RPM_BUILD_ROOT/%{_var}/lock/subsys/tclhttpd

# Fix some file permissions.
find $RPM_BUILD_ROOT/%{contentdir}/htdocs -type f -exec chmod a-x {} \;
find $RPM_BUILD_ROOT/%{contentdir}/custom -type f -exec chmod a-x {} \;
find $RPM_BUILD_ROOT/%{contentdir}/htdocs -name \*.cgi -exec chmod a+x {} \;
find $RPM_BUILD_ROOT/%{contentdir}/custom -name \*.cgi -exec chmod a+x {} \;

%pre
# The "tclhttpd" user is used so that we don't have to run the
# server as "root" or "nobody".
user_uid=`id -u tclhttpd 2>/dev/null`
if [ x"$user_uid" = x ] ; then
    useradd -r -s /sbin/nologin -d %{contentdir} -M \
            -c 'Tclhttpd' \
            tclhttpd >/dev/null || :
fi

%post
if [ $1 -eq 1 ] ; then 
    # Initial installation 
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ] ; then
    # Package removal, not upgrade
    /bin/systemctl --no-reload disable tclhttpd.service > /dev/null 2>&1 || :
    /bin/systemctl stop tclhttpd.service > /dev/null 2>&1 || :
fi

%postun
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    # Package upgrade, not uninstall
    /bin/systemctl try-restart tclhttpd.service >/dev/null 2>&1 || :
fi

%triggerun -- tclhttpd < 3.5.1-23
# Save the current service runlevel info
# User must manually run systemd-sysv-convert --apply tclhttpd
# to migrate them to systemd targets
/usr/bin/systemd-sysv-convert --save tclhttpd >/dev/null 2>&1 ||:

# Run these because the SysV package being removed won't do them
/sbin/chkconfig --del tclhttpd >/dev/null 2>&1 || :
/bin/systemctl try-restart tclhttpd.service >/dev/null 2>&1 || :

%files
%doc README README.* WHATSNEW license.terms
%{tcl_sitelib}/%{name}%{version}
%{_bindir}/tclhttpd
%config(noreplace) %attr(-,tclhttpd,tclhttpd) %{_sysconfdir}/%{name}
%{_mandir}/man1/*
%config(noreplace) %contentdir
%ghost %attr(-,tclhttpd,tclhttpd) %dir %{_localstatedir}/run/tclhttpd
%attr(-,tclhttpd,tclhttpd) %dir %{_localstatedir}/log/tclhttpd
%{_unitdir}/tclhttpd.service
%{tcl_sitearch}/crypt1.0
%{tcl_sitearch}/limit1.0
%doc src/README
%ghost %{_localstatedir}/lock/subsys/tclhttpd



%changelog
* Mon Nov 04 2024 ns80 <ns80> 3.5.1-9.mga10
+ Revision: 2112378
- fix building with GCC 14

* Thu Mar 24 2022 umeabot <umeabot> 3.5.1-8.mga9
+ Revision: 1824195
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 3.5.1-7.mga8
+ Revision: 1517395
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 3.5.1-6.mga7
+ Revision: 1301336
- Mageia 7 Mass Rebuild

* Thu Jan 07 2016 danf <danf> 3.5.1-5.mga6
+ Revision: 920258
- Added result.patch to enable backward compatibility in Tcl 8.6
- Switched to %%autopatch

* Wed Oct 15 2014 umeabot <umeabot> 3.5.1-4.mga5
+ Revision: 740042
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.5.1-3.mga5
+ Revision: 689742
- Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 3.5.1-2.mga4
+ Revision: 538929
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 joequant <joequant> 3.5.1-1.mga4
+ Revision: 491120
- ghost the dir in /var/run
- remove run
- imported package tclhttpd

